Class: RandomVariable::Exponential
- Inherits:
-
Object
- Object
- RandomVariable::Exponential
- Defined in:
- lib/distros.rb
Class Method Summary collapse
-
.new(mean) ⇒ Object
create a new Exponential Random Variable with a mean of
mean.
Class Method Details
.new(mean) ⇒ Object
create a new Exponential Random Variable with a mean of mean
60 61 62 |
# File 'lib/distros.rb', line 60 def self.new(mean) intern_new(mean) end |